@@ -13,15 +13,19 @@ fi
 PATH=/usr/local/src/gnu/gnulib:${PATH}
 mods="
 	faccessat
+	fdopendir
 	fstatat
 	futimens
 	getline
 	mkdirat
 	openat
+	progname
 	readlinkat
 	renameat
+	stat-time
 	strncat
 	symlinkat
+	sys_stat
 	unlinkat
 	utimensat
 "
