@@ -1,7 +1,7 @@
 /*
  * Copyright 2005-2010 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
- * $Header: /var/cvsroot/gentoo-projects/portage-utils/qgrep.c,v 1.29 2011/03/17 03:01:19 vapier Exp $
+ * $Header: /var/cvsroot/gentoo-projects/portage-utils/qgrep.c,v 1.30 2011/10/03 01:25:54 vapier Exp $
  *
  * Copyright 2005-2010 Ned Ludd        - <solar@gentoo.org>
  * Copyright 2005-2010 Mike Frysinger  - <vapier@gentoo.org>
@@ -47,7 +47,7 @@ static const char * const qgrep_opts_help[] = {
 	"Print <arg> lines of trailing context",
 	COMMON_OPTS_HELP
 };
-static const char qgrep_rcsid[] = "$Id: qgrep.c,v 1.29 2011/03/17 03:01:19 vapier Exp $";
+static const char qgrep_rcsid[] = "$Id: qgrep.c,v 1.30 2011/10/03 01:25:54 vapier Exp $";
 #define qgrep_usage(ret) usage(ret, QGREP_FLAGS, qgrep_long_opts, qgrep_opts_help, lookup_applet_idx("qgrep"))
 
 char qgrep_name_match(const char*, const int, depend_atom**);
@@ -363,23 +363,12 @@ int qgrep_main(int argc, char **argv)
 
 	/* pre-compile regexps once for all */
 	if (do_regex) {
-		int ret;
-		char err[256];
 		if (invert_match || *RED == '\0')
 			reflags |= REG_NOSUB;
-		if ((ret = regcomp(&preg, argv[optind], reflags))) {
-			if (regerror(ret, &preg, err, sizeof(err)))
-				err("regcomp failed: %s", err);
-			else
-				err("regcomp failed");
-		}
+		xregcomp(&preg, argv[optind], reflags);
 		reflags |= REG_NOSUB;
-		if (skip_pattern && (ret = regcomp(&skip_preg, skip_pattern, reflags))) {
-			if (regerror(ret, &skip_preg, err, sizeof(err)))
-				err("regcomp failed for --skip pattern: %s", err);
-			else
-				err("regcomp failed for --skip pattern");
-		}
+		if (skip_pattern)
+			xregcomp(&skip_preg, skip_pattern, reflags);
 	}
 
 	/* go look either in ebuilds or eclasses or VDB */
