@@ -1,7 +1,7 @@
 /*
  * Copyright 2005-2010 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
- * $Header: /var/cvsroot/gentoo-projects/portage-utils/qmerge.c,v 1.110 2011/10/02 22:09:47 vapier Exp $
+ * $Header: /var/cvsroot/gentoo-projects/portage-utils/qmerge.c,v 1.115 2011/12/19 04:58:09 vapier Exp $
  *
  * Copyright 2005-2010 Ned Ludd        - <solar@gentoo.org>
  * Copyright 2005-2010 Mike Frysinger  - <vapier@gentoo.org>
@@ -11,6 +11,16 @@
 
 #include <fnmatch.h>
 #include <glob.h>
+#include <sys/stat.h>
+/* This is a GNUlib hack, because GNUlib doesn't provide st_mtim members
+ * of struct stat, but instead provides wrappers to retrieve the time
+ * fields (stat-time module). We just define a macro in case people are
+ * building without autoconf. */
+#ifdef _GL_SYS_STAT_H
+# include "stat-time.h"
+#else
+# define get_stat_mtime(X) ((X)->st_mtim)
+#endif
 
 #ifndef GLOB_BRACE
 # define GLOB_BRACE     (1 << 10)	/* Expand "{a,b}" to "a" "b".  */
@@ -55,7 +65,7 @@ static const char * const qmerge_opts_help[] = {
 	COMMON_OPTS_HELP
 };
 
-static const char qmerge_rcsid[] = "$Id: qmerge.c,v 1.110 2011/10/02 22:09:47 vapier Exp $";
+static const char qmerge_rcsid[] = "$Id: qmerge.c,v 1.115 2011/12/19 04:58:09 vapier Exp $";
 #define qmerge_usage(ret) usage(ret, QMERGE_FLAGS, qmerge_long_opts, qmerge_opts_help, lookup_applet_idx("qmerge"))
 
 char search_pkgs = 0;
@@ -122,27 +132,29 @@ _q_static void fetch(const char *destdir, const char *src)
 		pid_t p;
 		int status;
 
-		const char *prog = (force_download || install) ? "wget" : pretend ? "echo" : "wget";
+		char prog[] = "wget";
+		char argv_c[] = "-c";
+		char argv_P[] = "-P";
+		char argv_q[] = "-q";
+		char *argv_dir = xstrdup(destdir);
 		char *argv[] = {
-			xstrdup(prog),
-			xstrdup("-c"),
-			xstrdup("-P"),
-			xstrdup(destdir),
+			prog,
+			argv_c,
+			argv_P,
+			argv_dir,
 			buf,
-			quiet ? xstrdup("-q") : NULL,
+			quiet ? argv_q : NULL,
 			NULL,
 		};
+		if (!(force_download || install) && pretend)
+			strcpy(prog, "echo");
 		snprintf(buf, sizeof(buf), "%s/%s", binhost, src);
 
 		p = vfork();
 		if (p == 0)
 			_exit(execvp(prog, argv));
 
-		free(argv[0]);
-		free(argv[1]);
-		free(argv[2]);
-		free(argv[3]);
-		free(argv[5]);
+		free(argv_dir);
 
 		waitpid(p, &status, 0);
 #if 0
@@ -188,64 +200,41 @@ _q_static void qmerge_initialize(void)
 	}
 }
 
-_q_static char *best_version(const char *CATEGORY, const char *PN)
+struct qmerge_bv_state {
+	const char *catname;
+	const char *pkgname;
+	char buf[4096];
+	char *retbuf;
+};
+
+_q_static int qmerge_filter_cat(q_vdb_cat_ctx *cat_ctx, void *priv)
 {
-	/* XXX: The qlist code should be refactored to avoid this fork and I/O */
-	static char buf[4096];
-	ssize_t rret;
-	int status, pipefd[2];
-	pid_t p;
-	FILE *fp;
+	struct qmerge_bv_state *state = priv;
+	return strcmp(cat_ctx->name, state->catname) == 0;
+}
 
-	buf[0] = '\0';
-	if (pipe(pipefd))
-		return buf;
+_q_static int qmerge_best_version_cb(q_vdb_pkg_ctx *pkg_ctx, void *priv)
+{
+	struct qmerge_bv_state *state = priv;
+	if (qlist_match(pkg_ctx, state->buf, true))
+		strcpy(state->retbuf, state->buf);
+	return 0;
+}
 
-	snprintf(buf, sizeof(buf), "%s%s%s", (CATEGORY != NULL ? CATEGORY : ""),
-		(CATEGORY != NULL ? "/" : ""), PN);
+_q_static char *best_version(const char *catname, const char *pkgname)
+{
+	static char retbuf[4096];
+	struct qmerge_bv_state state = {
+		.catname = catname,
+		.pkgname = pkgname,
+		.retbuf = retbuf,
+	};
 
-	fflush(stdout);
+	snprintf(state.buf, sizeof(state.buf), "%s/%s", catname, pkgname);
+	retbuf[0] = '\0';
+	q_vdb_foreach_pkg(qmerge_best_version_cb, &state, qmerge_filter_cat);
 
-	switch ((p = fork())) {
-	/* Stupid -Cv screws up global state */
-	case 0: {
-		fclose(stdout);
-		close(pipefd[0]);
-		if (dup2(pipefd[1], STDOUT_FILENO) != STDOUT_FILENO)
-			exit(1);
-		stdout = fdopen(pipefd[1], "w");
-		if (!stdout)
-			exit(1);
-		run_applet_l("qlist", "-CIev", buf, NULL);
-		exit(0);
-	}
-	default:
-		close(pipefd[1]);
-		waitpid(p, &status, 0);
-	}
-
-	fp = fdopen(pipefd[0], "r");
-	if (!fp) {
-		close(pipefd[0]);
-		return buf;
-	}
-
-	rret = fread(buf, 1, sizeof(buf), fp);
-	if (rret > 0) {
-		char *s;
-
-		buf[rret] = '\0';
-
-		s = buf;
-		while ((s = strchr(s, '\n')) != NULL)
-			*s = ' ';
-		rmspace(buf);
-	}
-
-	/* takes care of close(pipefd[0]) */
-	fclose(fp);
-
-	return buf;
+	return retbuf;
 }
 
 _q_static int
@@ -604,16 +593,17 @@ merge_tree_at(int fd_src, const char *src, int fd_dst, const char *dst,
 			/* Do the actual data copy */
 			if (copy_file_fd(fd_srcf, fd_dstf)) {
 				warnp("could not write %s", cpath);
-				if (ftruncate(fd_dstf, 0))
+				if (ftruncate(fd_dstf, 0)) {
 					/* don't care */;
+				}
 				close(fd_srcf);
 				close(fd_dstf);
 				continue;
 			}
 
 			/* Preserve the file times */
-			times[0] = st.st_mtim;
-			times[1] = st.st_mtim;
+			times[0] = get_stat_mtime(&st);
+			times[1] = get_stat_mtime(&st);
 			futimens(fd_dstf, times);
 
 			close(fd_srcf);
@@ -655,8 +645,8 @@ merge_tree_at(int fd_src, const char *src, int fd_dst, const char *dst,
 			}
 
 			struct timespec times[2];
-			times[0] = st.st_mtim;
-			times[1] = st.st_mtim;
+			times[0] = get_stat_mtime(&st);
+			times[1] = get_stat_mtime(&st);
 			utimensat(subfd_dst, name, times, AT_SYMLINK_NOFOLLOW);
 		}
 
@@ -1790,7 +1780,7 @@ qmerge_add_set_file(const char *dir, const char *file, queue *set)
 }
 
 _q_static void *
-qmerge_add_set_system(void *data, char *buf, FILE *fp)
+qmerge_add_set_system(void *data, char *buf)
 {
 	queue *set = data;
 	char *s;
